@@ -1,7 +1,7 @@
 char *get_bookfile_path(void);
 GList *get_bookmark_dirlist(void);
 int open_bookmarks(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath, gpointer user_data);
-void set_book_combo(GtkTreeView * treeview);
+void set_book_combo(void);
 
 void reload_book(GtkTreeView *treeview);
 int add2bookmarks(GtkTreeView * treeview, char *path);
