@@ -915,7 +915,7 @@ void on_drag_data_get (GtkWidget * widget, GdkDragContext * context, GtkSelectio
 		sl = (selection_list_t *) tmp->data;
 		if (!gtk_tree_row_reference_valid(sl->reference)) return;
 		sprintf(files, "file:/%s\r\n", sl->en->path);
-		files += (strlen(sl->en->path) + strlen("file:") + 2);
+		files += (strlen(sl->en->path) + strlen("file:/") + 2);
 	    }
 	    
 	    break;
