@@ -411,6 +411,75 @@ insert_pixbuf_tag (		const gchar *id,
 	x_tgt=(scale-1)*width/scale, y_tgt=(scale-1)*width/scale;
     else if (strcmp(where,"E")==0) 
 	x_tgt=(scale-1)*width/scale, y_tgt=(scale-1)*width/scale/2;
+
+    
+#if 0 
+    {
+	/* with this we get the tag to have a transparent part
+	 * over the icon, but where the icon *is* transparent,
+	 * and the tag as well, the resulting pixbuf will be *not*
+	 * transparent here! (It will have the color of the filled
+	 * in rectangle.*/
+	GdkBitmap *mask_return;
+	GdkPixmap *sandbox,*pixmap;
+	static GdkGC *penGC=NULL;
+	GdkColormap *cmap=gdk_colormap_get_system();
+
+	
+	GdkPixbuf *pb=gdk_pixbuf_new_subpixbuf (*tgt,
+		x_tgt,y_tgt,
+		width/scale,height/scale);
+	
+	gdk_pixbuf_render_pixmap_and_mask_for_colormap (pb, 
+		cmap, 
+		&pixmap, NULL, 128);
+	
+	sandbox = gdk_pixmap_new((GdkDrawable *)pixmap, width/scale,height/scale,-1);
+	g_object_unref(pixmap);
+
+	if (!penGC) {
+	    GdkColor pen_color= {0,65535,65535,65535};
+	    gdk_colormap_alloc_color(cmap,&pen_color,TRUE,TRUE);
+	    penGC = gdk_gc_new ((GdkDrawable *)sandbox);
+	    gdk_gc_set_colormap (penGC,cmap);
+	    gdk_gc_set_foreground (penGC, &pen_color);
+	}
+	gdk_draw_rectangle (sandbox, penGC, TRUE, 0,0,width/scale,height/scale);
+	gdk_draw_pixbuf ((GdkDrawable *)sandbox,
+                         penGC,
+                         *tgt,x_tgt,y_tgt,
+			 0,0, /* dest */
+			 width/scale,height/scale,
+                         GDK_RGB_DITHER_NONE,0,0);
+	
+	
+		
+	gdk_pixbuf_render_pixmap_and_mask_for_colormap (tag, 
+		cmap, 
+		NULL, &mask_return, 128);
+	
+	gdk_gc_set_clip_mask   (penGC,mask_return);
+
+	gdk_draw_pixbuf ((GdkDrawable *)sandbox,
+                         penGC,
+                         tag,
+                         0,0, /* src */
+			 0,0, /* dest */
+			 width/scale,height/scale,
+                         GDK_RGB_DITHER_NONE,0,0);
+	gdk_gc_set_clip_mask   (penGC,NULL);
+	
+	gdk_pixbuf_get_from_drawable (tag,
+		(GdkDrawable *)sandbox,
+                cmap,
+                0,0,0,0,
+		width/scale,height/scale);
+	g_object_unref(G_OBJECT(sandbox));
+	g_object_unref(G_OBJECT(pb));
+	g_object_unref(G_OBJECT(mask_return));
+
+    }
+#endif
     gdk_pixbuf_copy_area (tag,0,0,width/scale,height/scale,*tgt,x_tgt,y_tgt);
     g_object_unref(G_OBJECT(tag));
 }
@@ -860,8 +929,7 @@ static GdkPixbuf *resolve_icon (tree_entry_t * en, tree_entry_t * p_en)
     if ( !cut && loc && IS_FILE(en->type) && !IS_NETWORK_TYPE(en->type) &&
 	 !IS_TRASH_TYPE(en->type) && !strstr(en->path, "/..Wastebasket") &&
 	 en->st->st_size <= max_preview_size*1024 && 
-	 (tree_details->preferences & IMAGE_PREVIEW ||
-	  (p_en && SHOWS_IMAGES(p_en->type)) 
+	  ((p_en && SHOWS_IMAGES(p_en->type)) 
 	 ) && (IS_IMAGE(loc))
 	)
     {
