@@ -756,7 +756,7 @@ count_hidden_files(gchar *path)
 }
 
 G_MODULE_EXPORT
-void set_entry_tag (GtkTreeView * treeview, tree_entry_t * en, off_t tama) 
+void set_entry_tag (tree_entry_t * en, off_t tama) 
 {
     int hcount;
 
