@@ -1,4 +1,4 @@
-int add2history(GtkTreeView * treeview, char *path);
+int add2history(char *path);
 int open_history(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath, gpointer user_data);
 
 
