@@ -63,6 +63,7 @@
 #include "terminal.h"
 #include "input.h"
 #include "misc.h"
+#include "recent.h"
 #include "entry.h"
 #include "xmcs-manager.h"
 
@@ -82,7 +83,6 @@ save_to_open_history(		gchar *path2save,
     gchar *basename;
 
     g_free(xdg_dir);
-
     if (!path2save) return;
     basename=g_path_get_basename(path2save);
     if ((d=DBH_open(dbh_file))==NULL){
@@ -338,7 +338,11 @@ on_run_path(		char *in_cmd,
     gchar **argv;
     gchar *wd=NULL;
     if (!g_file_test(in_cmd,G_FILE_TEST_EXISTS) && !MIME_is_valid_command(in_cmd)){
-	print_diagnostics("xfce/error",strerror(ENOEXEC),": ",in_cmd,NULL);
+	if (!g_file_test(in_cmd,G_FILE_TEST_EXISTS))
+	    print_diagnostics("xfce/error",strerror(ENOENT),": ",in_cmd,"\n",NULL);
+	else
+	    print_diagnostics("xfce/error",strerror(ENOEXEC),": ",in_cmd,"\n",NULL);
+	    
 	return FALSE;
     }
 
@@ -379,7 +383,9 @@ on_run_path(		char *in_cmd,
     }
     TRACE("going to runvwd");
     if (runvwd(wd,argv)){
- 	save_to_open_history(path,in_cmd,interm);
+	/* recent history: */
+	if (path) add2history(path); 
+	save_to_open_history(path,in_cmd,interm);
     }
     g_free(wd); 
     g_strfreev (argv);
