@@ -188,10 +188,14 @@ static void create_channel(void)
     rcfile=g_build_filename(xdg_dir,MCS_PLUGIN_FILE,NULL);
     g_free(xdg_dir);
     
-    if (!g_file_test (rcfile, G_FILE_TEST_EXISTS)){
+    /*
+     * seems 4.0 config file causes problems.
+     * better let the user reconfigure 
+     * */
+    /*if (!g_file_test (rcfile, G_FILE_TEST_EXISTS)){
 	g_free(rcfile);
 	rcfile=g_build_filename(OLDRCFILE,NULL);
-    }
+    }*/
 
     if (g_file_test (rcfile, G_FILE_TEST_EXISTS))
     {
