@@ -290,8 +290,10 @@ time2return:
 #endif
     set_icon(treemodel, iter);
 	
-#if 10
-    if(gtk_tree_model_iter_children(treemodel, &child, iter)){
+    if(!gtk_tree_model_iter_children(treemodel, &child, iter)){
+	insert_dummy_row(treemodel, iter,NULL,en,NULL,"");
+    }
+    else {
 #ifdef DEBUG
 	printf("DBG: doing children\n"); 
 #endif
@@ -306,7 +308,6 @@ time2return:
 	}
       } while(gtk_tree_model_iter_next(treemodel, &child));
     }
-#endif
     
     hide_stop();
     if(!tree_details->window) exit(1);
@@ -748,11 +749,11 @@ gboolean treeclick(GtkWidget * widget, GdkEventButton * event, gpointer data)
     				SET_IN_TERM(en->subtype);
 				double_click_run(en);
 			}
-			add2history(treeview, en->path);
+			if (en->path) add2history(en->path);
 		} else 
 		{      /* open with */
 			double_click_open_with(en);
-			add2history(treeview, en->path);
+			if (en->path) add2history(en->path);
 		}
 	    }
        	    else if(gtk_tree_model_iter_children(treemodel, &child, &iter)){
