@@ -645,16 +645,14 @@ GtkTreeView *init_xffm(int argc, char *argv[])
     /* XXX does this "activates-default" do anything??? */
     g_object_set(G_OBJECT (WIDGET("combo_entry2")), "activates-default", TRUE, NULL);
     g_object_set(G_OBJECT (WIDGET("input_entry")), "activates-default", TRUE, NULL);
-    {
-	int i;
-	/* NOTICE: keep names[] order in sync with on_sort_activate() 
-	 * at libs/refresh.c */
-	char *names[] = { "show_hidden1","preview_images1", NULL};
-	for(i = 0; names[i]; i++){
-	    g_signal_connect(G_OBJECT(WIDGET(names[i])), "activate", 
-			    GTK_SIGNAL_FUNC(on_sort_activate), (gpointer) ((long)i));
-	}
-    }
+ 
+    g_signal_connect(G_OBJECT(WIDGET("show_hidden1")), "activate", 
+			    GTK_SIGNAL_FUNC(toggle_preference),
+			    (gpointer) ((long)(SHOW_DOT|INDIVIDUAL_TOGGLE)));
+    g_signal_connect(G_OBJECT(WIDGET("preview_images1")), "activate", 
+			    GTK_SIGNAL_FUNC(toggle_preference),
+			    (gpointer) ((long)(IMAGE_PREVIEW|INDIVIDUAL_TOGGLE)));
+   
 
    
     /*if (!startup) startup=g_strdup(GETWD);*/
